# Using CI integrations

If you use GitHub Actions, you can start sending data to Launchable workspace very quickly. See the [github-actions.md](../resources/ci-tool-integrations/github-actions.md "mention") page for instructions.

Otherwise, see [using-test-runner-integrations.md](using-test-runner-integrations.md "mention") or [using-the-launchable-cli](using-the-launchable-cli/ "mention").
